@@ -4,6 +4,7 @@ import asyncio
 import io
 import os
 import sys
+import warnings
 from logging import Logger
 
 import shellous
@@ -23,6 +24,10 @@ _UNLAUNCHED_EXIT_CODE = -255
 _BSD = sys.platform.startswith("freebsd") or sys.platform == "darwin"
 
 AUDIT_EVENT_SUBPROCESS_SPAWN = "byllyfish/shellous.subprocess_spawn"
+"""Audit event raised by sys.audit() when shellous runs a subprocess.
+
+The audit event has one argument: the name of the command.
+"""
 
 
 def _is_cancelled(ex):
@@ -239,7 +244,13 @@ class _RunOptions:
 
         stdout = asyncio.subprocess.PIPE
 
+        # TODO: str|bytes as output are deprecated.
         if isinstance(output, (str, bytes, os.PathLike)):
+            if isinstance(output, (str, bytes)):
+                warnings.warn(
+                    "Using str|bytes as output file is deprecated",
+                    DeprecationWarning,
+                )
             mode = "ab" if append else "wb"
             stdout = open(output, mode=mode)  # pylint: disable=consider-using-with
             self.open_fds.append(stdout)
@@ -496,7 +507,7 @@ class Runner:
             self._audit_callback("stop", failure=type(ex).__name__)
             raise
         finally:
-            if self._cancelled and self.command.options.incomplete_result:
+            if self._cancelled and self.command.options.catch_cancelled_error:
                 # Raises ResultError instead of CancelledError.
                 self.result()
 
@@ -689,7 +700,7 @@ class Runner:
         if (
             self._cancelled
             and self._timed_out
-            and not self.command.options.incomplete_result
+            and not self.command.options.catch_cancelled_error
         ):
             raise asyncio.TimeoutError()
         return suppress
@@ -948,7 +959,7 @@ class PipeRunner:
             cmds[i + 1] = cmds[i + 1].stdin(read_fd, close=True)
 
         for i in range(cmd_count):
-            cmds[i] = cmds[i].set(return_result=True, incomplete_result=True)
+            cmds[i] = cmds[i].set(return_result=True, catch_cancelled_error=True)
 
         return cmds
 
